#
# spec file for package python-PyFxA
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017-2018 The openSUSE Project.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-PyFxA
Version:        0.7.9
Release:        1.3
Summary:        Firefox Accounts client library for Python
License:        MPL-2.0
Group:          Development/Languages/Python
URL:            https://github.com/mozilla/PyFxA
Source:         https://files.pythonhosted.org/packages/source/P/PyFxA/pyfxa-%{version}.tar.gz
BuildRequires:  %{python_module PyBrowserID}
BuildRequires:  %{python_module PyJWT}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module hawkauthlib}
BuildRequires:  %{python_module parameterized}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyotp}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.4.2}
BuildRequires:  %{python_module responses}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyBrowserID
Requires:       python-PyJWT
Requires:       python-cryptography
Requires:       python-hawkauthlib
Requires:       python-requests >= 2.4.2
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
This is python library for interacting with the Firefox Accounts ecosystem.

%prep
%autosetup -p1 -n pyfxa-%{version}
sed -i -e '/^#!\/usr\/bin\/env python/d' fxa/__main__.py
find ./ -type f -exec chmod -x {} +

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/fxa-client
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Exclude tests which require network connection +
# deprecated test_monkey_patch_for_gevent
includedTests="\
  not TestAuthClientAuthorizeToken and\
  not TestAuthClientVerifyCode and\
  not TestCachedClient and\
  not TestCoreClient and\
  not TestCoreClientSession and\
  not TestJwtToken and\
  not test_monkey_patch_for_gevent"
%pytest -k "${includedTests}" fxa/tests/

%post
%python_install_alternative fxa-client

%postun
%python_uninstall_alternative fxa-client

%files %{python_files}
%doc CHANGES.txt README.rst
%python_alternative %{_bindir}/fxa-client
%{python_sitelib}/fxa
%{python_sitelib}/pyfxa-%{version}.dist-info

%changelog
* Tue Nov  5 2024 pgajdos@suse.com
- version update to 0.7.9
  * Python3 support
  * Add support for v2 password hashes
  * Updated to pyproject.toml
  * Updated libraries
* Thu Mar 21 2024 Dirk Müller <dmueller@suse.com>
- update to 0.7.8:
  * Add retries to the APIClient session
* Wed Apr  6 2022 pgajdos@suse.com
- python-mock is not required for build
* Mon Feb 22 2021 Markéta Machová <mmachova@suse.com>
- Drop broken %%ifpython3 macro, we don't need setuptools during runtime
* Tue Sep 22 2020 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 0.7.7:
  * Fix incorrect validation of JWKs passed to oauth.Client
    constructor, which was actually *preventing* the caller from
    setting a correct value rather than checking that they did so.
- Fix check section: Use double quotes when defining the list of
  tests since single quotes mess with the pytest macro.
* Sat Jul 11 2020 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 0.7.6:
  * Add ability to configure a fixed list of JWT access token keys,
    by passing them as an argument to `oauth.Client()` rather than
    fetching them at runtime from the server.
  * Fix verification of JWT access token `typ` header.
  * Fix verification of `scope` list obtained from a JWT access
    token.
- Changes from version 0.7.5:
  * Add support for `reason` and `verification_method` keyword
    arguments to the `login` method.
- Changes from version 0.7.4:
  * Perform more complete checking of the `state` parameter when
    authorizing an OAuth code.
  * When verifying OAuth access tokens, try to verify them locally
    as a JWT rather than passing them to the remote verification
    endpoint.
- Add new dependency: PyJWT.
- Update existing dependency: six >= 1.14.
- Update list of excluded tests.
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Jul 26 2019 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 0.7.3:
  * Allow specifying a `ttl` when redeeming an authorization code.
* Mon Jun  3 2019 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 0.7.2:
  * Several cleans for Python3 compatibility.
  * Fix a bug which could accidentally introduce multiple slashes
    into the result of oauth.Client.get_redirect_url.
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.1:
  * Fix test bustage due to session verification.
  * Add support for TOTP.
- Add missing deps
- Enable tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Aug 13 2018 mcepl@suse.com
- Remove dependency on unittest2
* Sun May 13 2018 antoine.belvire@opensuse.org
- Update to version 0.6.0:
  * Add support for PKCE challenge and response in the OAuth flow.
  * Add ability to supply `keys_jwk` when starting an OAuth flow.
  * Improve scope-matching logic based on new FxA testcases,
    including handling of URL-format scopes.
* Fri Jan 12 2018 antoine.belvire@opensuse.org
- Update to version 0.5.0:
  * Add ability to login with unblock codes.
  * Tell testrunners to ignore some test helper utilities.
* Sat Dec  2 2017 antoine.belvire@opensuse.org
- Initial package: python-PyFxA 0.4.0.
